/**
 * Editor
 * component utilising AceEditor:
 * https://www.npmjs.com/package/react-ace
 */
import { useEffect, useState } from "react";
import AceEditor from "react-ace";
// enables autocomplete
import "ace-builds/src-noconflict/ext-language_tools.js";

// allows Ace to resolve location of modes, themes, etc
import "ace-builds/esm-resolver";

// some meta info about modes and themes
import modeList from "ace-builds/src-noconflict/ext-modelist";

// Enables handlebars and json syntax highlighting
import "ace-builds/src-noconflict/mode-handlebars";
import "ace-builds/src-noconflict/mode-json";

import { styled } from "@mui/material";
import { Box } from "@mui/system";

const defaultOptions = {
  useWorker: false,
  displayIndentGuides: false,
  enableBasicAutocompletion: true,
  enableLiveAutocompletion: true,
  enableSnippets: false,
  showLineNumbers: true,
  tabSize: 2
};

function getMode(modeName, fileName) {
  return modeName ?? modeList.getModeForPath(fileName ?? "").name;
}

/**
 * A code/console component. Note this cannot be *rendered* conditionally; if needed, hide
 * this component *visually* via css instead of logically via jsx and pass an empty string
 * to the editor value. Also note that height must be specified absolutely if the parent
 * does not specify an absolute height, otherwise this component won't render visibly.
 */
export function Editor({
  uniqueName,
  value = "null",
  onChange,
  mode,
  filename,
  theme = "monokai",
  width = "100%",
  height = "100%",
  readOnly = false,
  options = defaultOptions,
  className,
  ...delegated
}) {
  const [aceMode, setAceMode] = useState(getMode(mode, filename));

  useEffect(() => {
    setAceMode(getMode(mode, filename));
  }, [filename, mode]);

  return (
    <AceEditor
      className={`${className} CeuiEditor`}
      readOnly={readOnly}
      mode={aceMode}
      theme={theme}
      name={uniqueName}
      width={width}
      height={height}
      showPrintMargin={false}
      value={value}
      onChange={onChange}
      editorProps={{ $blockScrolling: true }}
      wrapEnabled
      fontSize={16}
      setOptions={options}
      {...delegated}
    />
  );
}

export const EditorBox = styled(Box)({
  display: "flex",
  flexFlow: "column",
  height: "100%"
});
