/**
 * JSONEditor variant component cypress testing
 * Due to lack of possibility to choose row for cursor start
 * we need to create a new blank line to type on in editor
 */
import { Box } from "@mui/material";
import { validation, schemaTwo } from "../../../mocks/Editor/Editor";
import { JSONEditor } from "../JSONEditor";

function JSONEditorTemplate({ validate, showAlerts = true }) {
  const options = {
    showAlerts,
    maxAlerts: 3,
    readOnly: false,
    schema: schemaTwo,
    theme: "monokai",
    mode: undefined,
    value: JSON.stringify(validate, null, 2)
  };

  return (
    <Box height="100vh">
      <JSONEditor
        name="test-editor"
        {...options}
      />
    </Box>
  );
}

describe("JSONEditor.spec.js", () => {
  const text = "The quick brown fox jumps over the lazy dog.";

  context("JSONEditor, valid JSON", () => {
    it("JSONEditor, valid", () => {
      cy.mount(
        <JSONEditorTemplate
          showAlerts={false}
          validate={validation.valid}
        />
      );
      cy.get("#test-editor").type(`{pageUp}${text}{enter}`);
      // We need to make a clear row to be able to find it later
      cy.get("#test-editor").find(".ace_error").should("not.exist");

      cy.contains(text).should("exist");
      cy.get("#test-editor + [role=alert]").should("not.exist");
    });
  });

  context("JSONEditor, invalid JSON", () => {
    it("JSONEditor, invalid", () => {
      cy.mount(<JSONEditorTemplate validate={validation.invalid} />);
      cy.get("#test-editor").find(".ace_error").should("exist");
      cy.get("#test-editor + [role=alert]").should("exist");
    });

    it("JSONEditor, invalid JSON, no alert", () => {
      cy.mount(
        <JSONEditorTemplate
          showAlerts={false}
          validate={validation.invalid}
        />
      );
      cy.get("#test-editor").type(`{pageUp}${text}{enter}`);
      // We need to make a clear row to be able to find it later
      cy.get("#test-editor").find(".ace_error").should("exist");

      cy.contains(text).should("exist");
      cy.get("#test-editor + [role=alert]").should("not.exist");
    });
  });
});
