import AccessTimeIcon from "@mui/icons-material/AccessTime";
import { Tooltip, Typography } from "@mui/material";
import LabeledIcon from "../LabeledIcon";
import moment from "moment";
import { formatDateAndTime } from "../../../lib/Time-Utils";
import { bool } from "prop-types";

const formattedDuration = ({ startDate, finishDate }) => {
  if (startDate && finishDate) {
    return moment
      .utc(finishDate.getTime() - startDate.getTime())
      .format("HH:mm:ss");
  } else {
    return null;
  }
};

const propTypes = {
  /** Date that is start or creation date */
  createOrStartDate: Date,
  /** Date job is finished */
  finishedAt: Date,
  /** If to render the inner contents */
  textOnly: bool
};

export const Duration = ({ createOrStartDate, finishedAt, textOnly }) => {
  const duration = formattedDuration({
    finishDate: new Date(finishedAt),
    startDate: new Date(createOrStartDate)
  });

  const formattedFinishedAt = formatDateAndTime(finishedAt);

  return (
    <Tooltip
      title={`Finished ${formattedFinishedAt}`}
      aria-label={`Finished ${formattedFinishedAt}, after ${duration}`}
    >
      {textOnly ? (
        <Typography>{`${duration}`}</Typography>
      ) : (
        <LabeledIcon
          label={`${duration}`}
          LabelProps={{ variant: "body2" }}
          labelPosition="right"
          Icon={AccessTimeIcon}
          IconProps={{ fontSize: "small" }}
        />
      )}
    </Tooltip>
  );
};

Duration.prototypes = propTypes;
