import { useEffect, useState } from "react";
import { JSONEditor } from "../../components/code/JSONEditor";
import { sbDisabledArg } from "../utils/common-args";
import { schema, invalid } from "./data";

// some meta info about modes and themes
import themeList from "ace-builds/src-noconflict/ext-themelist";
import modeList from "ace-builds/src-noconflict/ext-modelist";

const editorModes = Object.keys(modeList.modesByName);
const editorThemes = Object.keys(themeList.themesByName);

export default {
  title: "Code/JSONEditor"
};

export const Validate = (args) => {
  const [value, setValue] = useState();
  useEffect(() => {
    setValue(args.value);
  }, [args.filename, args.value]);

  return (
    <JSONEditor
      name="example-editor"
      {...args}
      value={value}
      onChange={setValue}
    />
  );
};

Validate.args = {
  showAlerts: true,
  maxAlerts: 3,
  readOnly: false,
  schema: schema,
  theme: "monokai",
  value: JSON.stringify(invalid, null, 2)
};

Validate.argTypes = {
  filename: {
    options: ["startup.sh", "startup.mustache", "schema.json", "Editor.js"],
    control: { type: "select" }
  },
  mode: {
    options: [null, ...editorModes],
    control: { type: "select" }
  },
  theme: {
    options: editorThemes,
    control: { type: "select" }
  },
  schema: sbDisabledArg,
  value: sbDisabledArg
};
